#!/usr/bin/perl
#-------------------------------------------------------------------------------
#	$Id: gpxindex.pl,v 1.1 2019/07/10 00:12:55 wolf Exp $
#-------------------------------------------------------------------------------
#
#	Nutzung:
#		./gpxindex.pl *.gpx >index.csv
#	oder
#		perl.exe gpxindex.pl *.gpx >index.csv
#
#-------------------------------------------------------------------------------
#	Siehe:	https://www.netzwolf.info/ol2/trackloader.html
#-------------------------------------------------------------------------------

use strict;
use warnings FATAL => "all";

foreach my $pattern (@ARGV) {
		foreach my $gpx (glob($pattern)) {

	if (!open (GPX, '<', $gpx)) {

		warn "$gpx: $!\n";
		next;
	}

	my $minLon = +1e10;
	my $minLat = +1e10;
	my $maxLon = -1e10;
	my $maxLat = -1e10;

	my $name='';
	my $desc='';

	while (<GPX>) {

		$name = $1 if !$name && m#<name>([^<]+)</name>#;
		$desc = $1 if !$desc && m#<desc>([^<]+)</desc>#;

		next unless m#<trkpt([^<>]+)#;

		my $args = $1;

		next unless $args =~ m#\blat="(-?\d+\.?\d*)"#;
		my $lat = $1;

		next unless $args =~ m#\blon="(-?\d+\.?\d*)"#;
		my $lon = $1;

		$minLon = $lon if $lon<$minLon;
		$minLat = $lat if $lat<$minLat;
		$maxLon = $lon if $lon>$maxLon;
		$maxLat = $lat if $lat>$maxLat;
	}

	if ($minLon>$maxLon || $minLat>$maxLat) {

		warn "$gpx: keine Koordinaten gefunden.\n";
		next;
	}

	$name = &entityDecode($name) =~ s#[][]##gr;
	$desc = &entityDecode($desc);

	my $file = $gpx =~ s#\.gpx#.htm#r;
	my $descURL = -f $file ? $file : '';

	my $line = join("\t", $gpx, $minLon, $minLat, $maxLon, $maxLat, $name, $desc, $descURL);

	$line =~ s#\t+$##;
	print "${line}\n";
}}

sub entityDecode {

	my ($s) = @_;

	$s =~ s#&lt;#<#g;
	$s =~ s#&gt;#>#g;
	$s =~ s#&quot;#"#g;
	$s =~ s#&apos;#'#g;
	$s =~ s#&amp;#&#g;

	return $s;
}

#-------------------------------------------------------------------------------
#	$Id: gpxindex.pl,v 1.1 2019/07/10 00:12:55 wolf Exp $
#-------------------------------------------------------------------------------
